diff --git a/view/profile_vcard.tpl b/view/profile_vcard.tpl
index ecdb5280..cab732cc 100644
--- a/view/profile_vcard.tpl
+++ b/view/profile_vcard.tpl
@@ -2,8 +2,21 @@
+
{{ if $pdesc }}$profile.pdesc
{{ endif }}
diff --git a/view/theme/quattro/quattro.less b/view/theme/quattro/quattro.less
index 2c4e0464..01d0b94b 100644
--- a/view/theme/quattro/quattro.less
+++ b/view/theme/quattro/quattro.less
@@ -35,7 +35,7 @@ a:hover {color: @LinkHover; text-decoration: underline; }
.tool {
height: auto; overflow: auto;
.label { float: left;}
- .icon { float: right; }
+ .action { float: right; }
}
/* popup notifications */
@@ -168,11 +168,11 @@ ul.menu-popup {
.shadow();
- a { display: block; color: @MenuItem; padding: 5px 10px;}
+ a { display: block; color: @MenuItem; padding: 5px 10px; text-decoration: none;}
a:hover { background-color: @MenuItemHoverBg; }
.menu-sep { border-top: 1px solid @MenuItemSeparator; }
li { float: none; overflow: auto; height: auto; display: block; }
-
+ li img { float: left; width: 16px; height: 16px; padding-right: 5px;}
.empty {
padding: 5px;
text-align: center;
diff --git a/view/theme/quattro/style.css b/view/theme/quattro/style.css
index 0fce02f0..6daef77a 100644
--- a/view/theme/quattro/style.css
+++ b/view/theme/quattro/style.css
@@ -92,7 +92,7 @@ a:hover {
.tool .label {
float: left;
}
-.tool .icon {
+.tool .action {
float: right;
}
/* popup notifications */
@@ -268,6 +268,7 @@ ul.menu-popup a {
display: block;
color: #2d2d2d;
padding: 5px 10px;
+ text-decoration: none;
}
ul.menu-popup a:hover {
background-color: #bdcdd4;
@@ -281,6 +282,12 @@ ul.menu-popup li {
height: auto;
display: block;
}
+ul.menu-popup li img {
+ float: left;
+ width: 16px;
+ height: 16px;
+ padding-right: 5px;
+}
ul.menu-popup .empty {
padding: 5px;
text-align: center;
diff --git a/boot.php b/boot.php
index c1311601..10195c2b 100644
--- a/boot.php
+++ b/boot.php
@@ -860,9 +860,36 @@ function profile_sidebar($profile, $block = 0) {
$connect = False;
// show edit to yourself
if ($profile['uid'] == local_user()) {
$profile['edit'] = array($a->get_baseurl(). '/profiles', t('Profiles'),"", t('Manage/edit profiles'));
+
+ $r = q("SELECT * FROM `profile` WHERE `uid` = %d",
+ local_user());
+
+ $profile['menu'] = array(
+ 'chg_photo' => t('Change profile photo'),
+ 'cr_new' => t('Create New Profile'),
+ 'entries' => array(),
+ );
+
+ if(count($r)) {
+
+ foreach($r as $rr) {
+ $profile['menu']['entries'][] = array(
+ 'photo' => $rr['thumb'],
+ 'id' => $rr['id'],
+ 'alt' => t('Profile Image'),
+ 'profile_name' => $rr['profile-name'],
+ 'visible' => (($rr['is-default']) ? '' . t('visible to everybody') . ''
+ : '' . t('Edit visibility') . '')
+ );
+ }
+
+
+ }
+
+
}
@@ -860,9 +860,36 @@ function profile_sidebar($profile, $block = 0) {
$connect = False;
- // show edit to yourself
+ // show edit profile to yourself
if ($profile['uid'] == local_user()) {
$profile['edit'] = array($a->get_baseurl(). '/profiles', t('Profiles'),"", t('Manage/edit profiles'));